<!doctype html><html lang="en"><head><meta charset="utf-8"/><link rel="icon" href="{{ base_path }}/static-files/favicon.ico"/><meta name="viewport" content="minimum-scale=1,initial-scale=1,width=device-width"/><meta name="theme-color" content="#000000"/><meta name="description" content="Open-source, self-hosted AI experiment tracking tool"/><style>.preloader{position:fixed;top:0;bottom:0;right:0;left:0;background-color:#fff;z-index:1000;display:flex;justify-content:center;align-items:center}.preloader-wrapper{display:flex;flex-direction:column;align-items:center}.preloader svg{transform:scale(1.5)}.progress-bar{height:4px;border-radius:1px;background-color:#f2f5fa;overflow:hidden;margin-top:50px;width:100px}.progress-bar-value{width:100%;height:100%;background-color:#4b9bff;animation:progress-animation 1s infinite linear;transform-origin:0 50%}@keyframes progress-animation{0%{transform:translateX(0) scaleX(0)}40%{transform:translateX(0) scaleX(.4)}100%{transform:translateX(100%) scaleX(.5)}}</style><script>document.write('<div id=\'preload-spinner\' class=\'preloader\'>\n        <div class=\'preloader-wrapper\'>\n        <svg overflow=\'overlay\' id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" width="56.71503" height="56.50146">\n  <g id="Logo">\n    <path fill="#57aeea" class="cls-1" d="M43.8887,2.55052A4.37315,4.37315,0,1,0,37.704,8.73494l10.98239,10.983a4.373,4.373,0,1,0,6.18471-6.18411Z"/>\n    <path fill="#7869d0" class="cls-2" d="M11.46467,5.38778a4.37283,4.37283,0,1,0-6.18411,6.18411l39.472,39.472A4.37314,4.37314,0,0,0,50.9373,44.8595Z"/>\n    <path fill="#688bdd" class="cls-3" d="M24.98757,1.2809a4.37293,4.37293,0,1,0-6.18411,6.18441l30.44626,30.446a4.37293,4.37293,0,1,0,6.18411-6.18441Z"/>\n    <path fill="#8946c2" class="cls-4" d="M7.463,19.01562A4.37314,4.37314,0,1,0,1.27833,25.2L31.29946,55.22055a4.37314,4.37314,0,1,0,6.18471-6.18441Z"/>\n    <path fill="#9923b5" class="cls-5" d="M8.62889,37.81033a4.37315,4.37315,0,1,0-6.18471,6.18442l10.98239,10.983a4.373,4.373,0,1,0,6.18471-6.18411Z"/>\n  </g>\n</svg>\n  <div class="progress-bar">\n    <div class="progress-bar-value"></div>\n  </div>\n</div>\n    </div>')</script><link rel="manifest" href="{{ base_path }}/static-files/manifest.json"/><link rel="preload" as="script" href="{{ base_path }}/static-files/vs/editor/editor.main.js" crossorigin/><link rel="preload" as="font" href="{{ base_path }}/static-files/assets/inter/fonts/Inter.ttf" crossorigin/><link rel="preload" as="font" href="{{ base_path }}/static-files/assets/inconsolata/fonts/Inconsolata.ttf" crossorigin/><link rel="preload" as="font" href="{{ base_path }}/static-files/assets/icomoon/fonts/icomoon.eot" crossorigin/><link rel="preload" as="font" href="{{ base_path }}/static-files/assets/icomoon/fonts/icomoon.ttf" crossorigin/><link rel="preload" as="font" href="{{ base_path }}/static-files/assets/icomoon/fonts/icomoon.woff" crossorigin/><link rel="stylesheet" href="{{ base_path }}/static-files/assets/inter/inter.css"/><link rel="stylesheet" href="{{ base_path }}/static-files/assets/inconsolata/inconsolata.css"/><link rel="stylesheet" href="{{ base_path }}/static-files/assets/icomoon/icomoonIcons.css"/><link rel="stylesheet" href="https://fonts.googleapis.com/icon?family=Material+Icons"/><title>Aim</title><script>!function(){var e=window.analytics=window.analytics||[];if(!e.initialize)if(e.invoked)window.console&&console.error&&console.error("Segment snippet included twice.");else{e.invoked=!0,e.methods=["trackSubmit","trackClick","trackLink","trackForm","pageview","identify","reset","group","track","ready","alias","debug","page","once","off","on","addSourceMiddleware","addIntegrationMiddleware","setAnonymousId","addDestinationMiddleware"],e.factory=function(t){return function(){var n=Array.prototype.slice.call(arguments);return n.unshift(t),e.push(n),e}};for(var t=0;t<e.methods.length;t++){var n=e.methods[t];e[n]=e.factory(n)}e.load=function(t,n){var a=document.createElement("script");a.type="text/javascript",a.async=!0,a.src="https://cdn.segment.com/analytics.js/v1/"+t+"/analytics.min.js";var r=document.getElementsByTagName("script")[0];r.parentNode.insertBefore(a,r),e._loadOptions=n},e.SNIPPET_VERSION="4.15.3"}}()</script><script>window.API_BASE_PATH="{{ base_path }}",window.externalPublicPath="{{ base_path }}/static-files/"</script><link href="{{ base_path }}/static-files/static/css/main.css?version=f6c60a1321cd4dfb5ced" rel="stylesheet"></head><body><noscript>You need to enable JavaScript to run this app.</noscript><div id="root"></div><script src="{{ base_path }}/static-files/static/js/runtime~main.js?version=f340abd5e4e97cbdabd0"></script><script src="{{ base_path }}/static-files/static/js/main.js?version=0b180de7e998c18c2d07"></script></body></html>