.RunDetailLogsTabWrapper{overflow:hidden;height:100%;max-height:100%}.RunDetailLogsTabWrapper .RunDetailLogsTab{border-left:.0625rem solid #dee6f3;border-right:.0625rem solid #dee6f3;height:100%;background-color:#fff}.RunDetailLogsTabWrapper .RunDetailLogsTab .Logs{height:100%;overflow-y:auto;overflow-x:auto;border-radius:.375rem}.RunDetailLogsTabWrapper .RunDetailLogsTab .Logs__wrapper{width:100%;height:100%;position:relative}.RunDetailLogsTabWrapper .RunDetailLogsTab .Logs__wrapper .overlay{display:none;height:3.125rem;width:100%;background:#fff;position:absolute;top:0;left:0}.RunDetailLogsTabWrapper .RunDetailLogsTab .Logs__wrapper .loading{display:flex;justify-content:center;align-items:center}.LogRow__line{color:#333;font-size:.875rem;padding:0 .75rem;font-family:"Inconsolata",monospace;font-variation-settings:"wdth" 82;width:100%;line-height:1.08;display:block;height:15px}
/*# sourceMappingURL=RunLogsTab.css?version=29e033e0eb72ccd767c4.map */