(this.webpackJsonpui_v2=this.webpackJsonpui_v2||[]).push([[17],{1516:function(a,s,e){"use strict";e.r(s);var t=e(0),i=e.n(t),r=e(63),n=e(259),c=e(345),m=e(11),u=e(404),b=e(16),l=e(14),j=e(1);function o(a){var s=a.runParams,e=a.isRunInfoLoading;return i.a.useEffect((function(){l.a(b.a.runDetails.tabs.params.tabView)}),[]),Object(j.jsx)(m.a,{children:Object(j.jsx)(n.a,{isLoading:e||!s,className:"runDetailParamsTabLoader",height:"100%",children:r.a.isEmpty(s)?Object(j.jsx)(c.a,{size:"xLarge",className:"runDetailParamsTabLoader",title:"No Params"}):Object(j.jsx)("div",{className:"RunDetailParamsTabWrapper",children:Object(j.jsx)("div",{className:"RunDetailParamsTab",children:Object(j.jsx)(u.a,{src:r.a.omit(s,"__system_params")})})})})})}s.default=Object(t.memo)(o)}}]);
//# sourceMappingURL=RunDetailParamsTab.js.map?version=e955a4e71f0c636d0346