.GitInfoCard .IllustrationBlock{margin-bottom:1.75rem}.GitInfoCard .InfoSection{overflow-y:scroll}.GitInfoCard .InfoSection .InfoCard{margin-right:2.5rem;min-width:-webkit-fit-content;min-width:-moz-fit-content;min-width:fit-content}.GitInfoCard .InfoSection .InfoCard:last-child{margin-right:0}.GitInfoCard .InfoSection .InfoCard .InfoCardLabel{margin-bottom:.25rem}.GitInfoCard .InfoSection .InfoCard .Icon__container{color:#1c2852}.GitInfoCard .InfoSection .InfoCard .InfoCardValue{text-align:center;background:#f8fafd;border:.0625rem solid #dee6f3;box-sizing:border-box;border-radius:.375rem;padding:.375rem}.GitInfoCard .InfoSection .InfoCard .InfoCardValue .InfoCardValueText{margin-left:.4375rem}.RunOverviewSidebar{width:20rem;min-width:20rem;overflow-y:auto;overflow-x:hidden;padding:2rem .5rem .5rem;position:-webkit-sticky;position:sticky;top:0}.RunOverviewSidebar h3{margin-bottom:.75rem}.RunOverviewSidebar__wrapper{height:-moz-fit-content;height:-webkit-fit-content;height:fit-content}.RunOverviewSidebar__section{margin:0 1rem 1.5rem}.RunOverviewSidebar__section__info__listItem{display:flex;align-items:center;height:1.75rem;margin-bottom:.125rem}.RunOverviewSidebar__section__info__listItem span{max-width:15rem;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.RunOverviewSidebar__section__info .Icon__container{font-size:.875rem;margin-right:.75rem}.RunOverviewSidebar__section__descriptionBox{padding-top:1.25rem}.RunOverviewSidebar__section__descriptionBox__header{display:flex;justify-content:space-between}.RunOverviewSidebar__section__descriptionBox__header a{text-decoration:unset}.RunOverviewSidebar__section__descriptionBox__header i{color:#83899e}.RunOverviewSidebar__section__descriptionBox__header h3{margin-top:.25rem}.RunOverviewSidebar__section__descriptionBox__description{display:flex;max-height:4.5rem;overflow:hidden;position:relative;word-break:break-all;flex-direction:column}.RunOverviewSidebar__section__descriptionBox__description .dots{background:#f8fafd;position:absolute;bottom:0;right:0;height:.775rem;justify-content:center;align-items:center;width:4.5rem;display:flex;justify-content:flex-end;padding-right:.25rem;cursor:pointer}.RunOverviewSidebar__section__descriptionBox__description.showAll{max-height:100%}.RunOverviewSidebar__section__descriptionBox__description.hasMore:after{content:"";position:absolute;bottom:0;left:0;height:.625rem;width:100%;z-index:1}.RunOverviewSidebar__section__descriptionBox__seeMoreButtonBox{width:100%;justify-content:flex-start;align-items:center;display:flex;padding-top:.125rem}.RunOverviewSidebar__section__descriptionBox__seeMoreButtonBox .Text{cursor:pointer}.RunOverviewSidebar__section__descriptionBox__seeMoreButtonBox .Text:hover{text-decoration:underline}.RunOverviewSidebar__section__tags-list{display:flex;align-items:center;overflow:auto}.RunOverviewSidebar__section__tags-list .Badge{margin-right:.5rem}.RunOverviewSidebar__section__tags-list .Badge:last-child{margin-right:0}.RunOverviewSidebar__section__insights{padding-top:1.5rem;margin:unset}.RunOverviewSidebar__section__insights h3{margin-left:1rem}.RunOverviewSidebar__section__Divider{margin:0 1rem}.RunOverviewSidebar__NavLink{display:flex;align-items:center;justify-content:space-between;height:2rem;padding:0 1rem;margin-bottom:.125rem;border-radius:.25rem;transition:background-color .18s ease-out;outline:none;text-decoration:none}.RunOverviewSidebar__NavLink:hover{background-color:#ebf0f8}.CodeBlock{background:#f2f3f4;border-radius:.375rem;padding:1em 3em 1em 1em;position:relative;min-height:3.5rem;display:flex;align-items:center;overflow:auto}.CodeBlock pre{margin:0;font-style:normal;font-weight:450;font-size:15px;line-height:1.3125em;overflow:auto;font-family:"Inconsolata",monospace;font-variation-settings:"wdth" 84px}.CodeBlock__copy__button{top:.75rem;right:1rem;color:#414b6d;display:inline-block;cursor:pointer;position:absolute;align-items:center;justify-content:center}.RunOverviewTabCLIArgumentsCard .IllustrationBlock{margin-bottom:1.75rem}.RunOverviewTab{display:flex;height:100%;justify-content:center;overflow-y:auto;padding:0 1rem}.RunOverviewTab__content{flex:1 1 100%;max-width:66.75rem}.RunOverviewTab__cardBox{margin-bottom:1.5rem}.RunOverviewTab__cardBox:first-child{margin-top:1.5rem}.RunOverviewTab__cardBox:last-child{display:inline-block}.RunOverviewTab__cardBox__tableTitleCount{margin-left:.25rem}.RunOverviewTab__cardBox__badge{height:1.25rem}.RunOverviewTab__cardBox__badge.emptyContext{background:#f8fafd;border:.0625rem solid #dee6f3;color:#414b6d}.RunOverviewTab .DataList .IllustrationBlock{height:100%}
/*# sourceMappingURL=RunOverviewTab.css?version=e03f76081d3b1dd7ad59.map */