.LineChart{background-color:#fff;height:100%;width:100%;position:relative;overflow:hidden;-webkit-user-select:none;user-select:none;min-width:9.375rem;min-height:9.375rem}.LineChart .unableToDrawText{font-size:.875rem;text-align:center;fill:#586069;position:absolute;top:50%;left:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);width:80%}.LineChart.backgroundRect{cursor:crosshair}.LineChart.zoomMode rect{cursor:zoom-in}.LineChart .HoverCircle{cursor:pointer;opacity:1;stroke-width:2.4;fill:#fff;border-radius:50%;paint-order:stroke}.LineChart .HoverCircle.focus{stroke-width:4;-webkit-clip-path:unset;clip-path:unset}.LineChart .HoverCircle.focus__shadow{stroke-width:12}.LineChart .HoverCircle.active{stroke-width:5}.LineChart .Attributes.highlight .HoverCircle:not(.active):not(.focus){opacity:.5}.LineChart .Attributes.highlight .inProgressLineIndicator:not(.active):not(.focus){opacity:.8}.LineChart .ChartMouseValue{position:absolute;box-sizing:border-box;padding:.375rem .5rem;background-color:#f7faff;border:1px solid #7a94cc;color:#243969;font-size:10px;font-weight:350;white-space:nowrap}.LineChart .ChartMouseValueXAxis{-webkit-transform:translateX(-50%);transform:translateX(-50%);border-radius:0 0 6px 6px;border-top:none;overflow:hidden}.LineChart .ChartMouseValueYAxis{-webkit-transform:translateY(-50%);transform:translateY(-50%);border-radius:6px 0 0 6px;border-right:none;overflow:hidden;box-shadow:inset -8px 0 5px -6px #3b5896}.LineChart .Lines{overflow:hidden}@media(-webkit-min-device-pixel-ratio:2),(min-resolution:192dpi){.LineChart .Lines.optimizeRendering{shape-rendering:optimizeSpeed}}.LineChart .Lines.highlight .AggrLine{opacity:.2}.LineChart .Lines.highlight .AggrArea.highlighted,.LineChart .Lines.highlight .AggrLine.highlighted{opacity:1}.LineChart .Lines.highlight>.Line:not(.active):not(.highlighted):not(.aggregated){stroke-width:1.5;opacity:.2}.LineChart .Lines.highlight>.AggrArea:not(.highlighted){opacity:.2}.LineChart .Line{stroke-width:1.5;opacity:1}.LineChart .Line.active{opacity:1;stroke-width:3}.LineChart .Line.highlighted{opacity:1;stroke-width:2.8}.LineChart .Line.aggregated{opacity:0;stroke-width:.4}.LineChart .Line.aggregated.active{opacity:.8;stroke-width:3}.LineChart .Line.aggregated.highlighted{opacity:.5;stroke-width:2.8}.LineChart .AggrLine{opacity:1;stroke-width:2.2}.LineChart .inProgressLineIndicator{-webkit-animation:inProgressIndicator .5s cubic-bezier(.6,-.03,.22,.76) infinite;animation:inProgressIndicator .5s cubic-bezier(.6,-.03,.22,.76) infinite;opacity:1;paint-order:stroke;cursor:pointer;-webkit-filter:drop-shadow(0 0 .5px #fff) drop-shadow(0 0 .5px #fff) drop-shadow(0 0 .5px #fff);filter:drop-shadow(0 0 .5px #ffffff) drop-shadow(0 0 .5px #ffffff) drop-shadow(0 0 .5px #ffffff)}@-webkit-keyframes inProgressIndicator{0%{stroke-width:3}50%{stroke-width:5}to{stroke-width:3}}@keyframes inProgressIndicator{0%{stroke-width:3}50%{stroke-width:5}to{stroke-width:3}}
/*# sourceMappingURL=RunDetailMetricsAndSystemTab.css?version=914c8fb1a9926c6f0598.map */